==> spark-nlp-4.0.2.tar.gz: spark-nlp-4.0.2/sparknlp/annotator/embeddings/__init__.py <==
#  Copyright 2017-2022 John Snow Labs
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

"""Module of annotators for text embeddings."""
from sparknlp.annotator.embeddings.albert_embeddings import *
from sparknlp.annotator.embeddings.bert_embeddings import *
from sparknlp.annotator.embeddings.bert_sentence_embeddings import *
from sparknlp.annotator.embeddings.camambert_embeddings import *
from sparknlp.annotator.embeddings.chunk_embeddings import *
from sparknlp.annotator.embeddings.deberta_embeddings import *
from sparknlp.annotator.embeddings.distil_bert_embeddings import *
from sparknlp.annotator.embeddings.doc2vec import *
from sparknlp.annotator.embeddings.elmo_embeddings import *
from sparknlp.annotator.embeddings.longformer_embeddings import *
from sparknlp.annotator.embeddings.roberta_embeddings import *
from sparknlp.annotator.embeddings.roberta_sentence_embeddings import *
from sparknlp.annotator.embeddings.sentence_embeddings import *
from sparknlp.annotator.embeddings.universal_sentence_encoder import *
from sparknlp.annotator.embeddings.word2vec import *
from sparknlp.annotator.embeddings.word_embeddings import *
from sparknlp.annotator.embeddings.xlm_roberta_embeddings import *
from sparknlp.annotator.embeddings.xlm_roberta_sentence_embeddings import *
from sparknlp.annotator.embeddings.xlnet_embeddings import *

==> spark-nlp-4.2.3.tar.gz: spark-nlp-4.2.3/sparknlp/annotator/embeddings/__init__.py <==
#  Copyright 2017-2022 John Snow Labs
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

"""Module of annotators for text embeddings."""
from sparknlp.annotator.embeddings.albert_embeddings import *
from sparknlp.annotator.embeddings.bert_embeddings import *
from sparknlp.annotator.embeddings.bert_sentence_embeddings import *
from sparknlp.annotator.embeddings.camembert_embeddings import *
from sparknlp.annotator.embeddings.chunk_embeddings import *
from sparknlp.annotator.embeddings.deberta_embeddings import *
from sparknlp.annotator.embeddings.distil_bert_embeddings import *
from sparknlp.annotator.embeddings.doc2vec import *
from sparknlp.annotator.embeddings.elmo_embeddings import *
from sparknlp.annotator.embeddings.longformer_embeddings import *
from sparknlp.annotator.embeddings.roberta_embeddings import *
from sparknlp.annotator.embeddings.roberta_sentence_embeddings import *
from sparknlp.annotator.embeddings.sentence_embeddings import *
from sparknlp.annotator.embeddings.universal_sentence_encoder import *
from sparknlp.annotator.embeddings.word2vec import *
from sparknlp.annotator.embeddings.word_embeddings import *
from sparknlp.annotator.embeddings.xlm_roberta_embeddings import *
from sparknlp.annotator.embeddings.xlm_roberta_sentence_embeddings import *
from sparknlp.annotator.embeddings.xlnet_embeddings import *
